@@ -1,5 +1,6 @@
 from .client import Client
 from .store import Store
+from .device import Device
 from .reference import Reference
 from .event import Event
 from .extension import Extension
@@ -10,6 +11,7 @@ class ApiClient:
     _client: Client = None
     store: Store = None
     reference: Reference = None
+    device: Device = None
     client: Client = None
     event: Event = None
     extension: Extension = None
@@ -20,6 +22,7 @@ class ApiClient:
         self._client = Client(url, application, headers=headers)
         self.store = Store(self._client)
         self.reference = Reference(self._client)
+        self.device = Device(self._client)
         self.event = Event(self._client)
         self.extension = Extension(self._client)
         self.relation = Relation(self._client)
